pub(crate) struct SubordinateInfo {
pub uid: u32,
pub gid: u32,
pub subuid: u32,
pub subgid: u32,
}Available on Linux only.
Represents a single (subuid,subgid) pair for a user and their group.
In practice there are usually many more subordinate ids than just one, but for oci builds we only need one. If we ever need more, we can improve this implementation.
Fields
uid: u32gid: u32subuid: u32subgid: u32Implementations
Sourceimpl SubordinateInfo
impl SubordinateInfo
Sourcepub(crate) fn for_effective_user() -> Result<SubordinateInfo, SubordinateError>
pub(crate) fn for_effective_user() -> Result<SubordinateInfo, SubordinateError>
Parses /etc/subuid and /etc/subgid and returns a single SubordinateInfo for the effective user.