fn configure_mounts<'a>(
rootless: bool,
allow_network: bool,
scratch_paths: impl IntoIterator<Item = &'a Path>,
inputs: impl Iterator<Item = (&'a PathComponent, &'a Node)>,
inputs_dir: &Path,
ro_host_mounts: impl IntoIterator<Item = (&'a Path, &'a Path)>,
) -> Result<Vec<Mount>, OciSpecError>Available on Linux only.
Return the Mounts part of the OCI Runtime spec. It first sets up the standard mounts, then scratch paths, bind mounts for all inputs, and finally read-only paths from the hosts.